@@ -1,134 +1,139 @@
 <?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="ja">
 <context>
-    <name>mxremastercc</name>
+    <name>MainWindow</name>
     <message>
-        <location filename="mxremastercc.ui" line="14"/>
+        <location filename="../mainwindow.ui" line="14"/>
         <source>MX Remastercc</source>
-        <translation>MX Remastercc</translation>
+        <translation>MX リマスターCC</translation>
     </message>
     <message>
-        <location filename="mxremastercc.ui" line="64"/>
+        <location filename="../mainwindow.ui" line="64"/>
         <source>Persistence</source>
         <translation>パーシステンス</translation>
     </message>
     <message>
-        <location filename="mxremastercc.ui" line="81"/>
+        <location filename="../mainwindow.ui" line="81"/>
         <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p align=&quot;center&quot;&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;This tool allows you to rework an ISO while running Live. &lt;/span&gt;&lt;/p&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Remaster&lt;/span&gt; allows you to change files, applications and settings with the goal of producing a new master copy for storage or distribution. &lt;/p&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Persistence&lt;/span&gt; allows you to retain data, settings and installed programs when the machine gets switched off for personal use.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
         <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p align=&quot;center&quot;&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;このツールはライブ実行する ISO を手直しすることができます。 &lt;/span&gt;&lt;/p&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;リマスター&lt;/span&gt; ストレージや配布用の新しいマスターコピーを生成するために、ファイルやアプリケーション、設定を変更することができます。&lt;/p&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;パーシステンス&lt;/span&gt; マシンを個人利用するときに、データ・設定やインストールしたプログラムを保持することができます。&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
     </message>
     <message>
-        <location filename="mxremastercc.ui" line="133"/>
+        <location filename="../mainwindow.ui" line="133"/>
         <source>Display help </source>
-        <translation>ヘルプを表示</translation>
+        <translation>ヘルプの表示</translation>
     </message>
     <message>
-        <location filename="mxremastercc.ui" line="136"/>
+        <location filename="../mainwindow.ui" line="136"/>
         <source>Help</source>
         <translation>ヘルプ</translation>
     </message>
     <message>
-        <location filename="mxremastercc.ui" line="143"/>
+        <location filename="../mainwindow.ui" line="143"/>
         <source>Alt+H</source>
         <translation>Alt+H</translation>
     </message>
     <message>
-        <location filename="mxremastercc.ui" line="175"/>
+        <location filename="../mainwindow.ui" line="175"/>
         <source>About this application</source>
         <translation>このアプリケーションについて</translation>
     </message>
     <message>
-        <location filename="mxremastercc.ui" line="178"/>
+        <location filename="../mainwindow.ui" line="178"/>
         <source>About...</source>
-        <translation>情報...</translation>
+        <translation>概要...</translation>
     </message>
     <message>
-        <location filename="mxremastercc.ui" line="185"/>
+        <location filename="../mainwindow.ui" line="185"/>
         <source>Alt+B</source>
         <translation>Alt+B</translation>
     </message>
     <message>
-        <location filename="mxremastercc.ui" line="217"/>
+        <location filename="../mainwindow.ui" line="217"/>
         <source>Quit application</source>
         <translation>アプリケーションの終了</translation>
     </message>
     <message>
-        <location filename="mxremastercc.ui" line="220"/>
+        <location filename="../mainwindow.ui" line="220"/>
         <source>Close</source>
         <translation>閉じる</translation>
     </message>
     <message>
-        <location filename="mxremastercc.ui" line="227"/>
+        <location filename="../mainwindow.ui" line="227"/>
         <source>Alt+N</source>
         <translation>Alt+N</translation>
     </message>
     <message>
-        <location filename="mxremastercc.ui" line="264"/>
+        <location filename="../mainwindow.ui" line="264"/>
         <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600; text-decoration: underline;&quot;&gt;Basic operations&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
         <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600; text-decoration: underline;&quot;&gt;基本操作&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
     </message>
     <message>
-        <location filename="mxremastercc.ui" line="274"/>
+        <location filename="../mainwindow.ui" line="274"/>
         <source>Remaster</source>
         <translation>リマスター</translation>
     </message>
     <message>
-        <location filename="mxremastercc.ui" line="300"/>
+        <location filename="../mainwindow.ui" line="301"/>
         <source>Save root persistence</source>
         <translation>root 権限の保存</translation>
     </message>
     <message>
-        <location filename="mxremastercc.ui" line="313"/>
+        <location filename="../mainwindow.ui" line="315"/>
         <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600; text-decoration: underline;&quot;&gt;Optional operations&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
         <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600; text-decoration: underline;&quot;&gt;オプション操作&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
     </message>
     <message>
-        <location filename="mxremastercc.ui" line="323"/>
+        <location filename="../mainwindow.ui" line="325"/>
         <source>Configure live persistence</source>
         <translation>live 権限の設定</translation>
     </message>
     <message>
-        <location filename="mxremastercc.cpp" line="51"/>
-        <location filename="mxremastercc.cpp" line="100"/>
+        <location filename="../mainwindow.cpp" line="54"/>
+        <location filename="../mainwindow.cpp" line="103"/>
         <source>MX Remaster Control Center</source>
         <translation>MX リマスター コントロールセンター</translation>
     </message>
     <message>
-        <location filename="mxremastercc.cpp" line="99"/>
+        <location filename="../mainwindow.cpp" line="82"/>
+        <source>MX RemasterCC</source>
+        <translation>MX RemasterCC</translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.cpp" line="102"/>
         <source>About MX Remaster Control Center</source>
         <translation>MX リマスター コントロールセンターについて</translation>
     </message>
     <message>
-        <location filename="mxremastercc.cpp" line="100"/>
+        <location filename="../mainwindow.cpp" line="104"/>
         <source>Version: </source>
-        <translation>バージョン: </translation>
+        <translation>バージョン：</translation>
     </message>
     <message>
-        <location filename="mxremastercc.cpp" line="101"/>
+        <location filename="../mainwindow.cpp" line="105"/>
         <source>This program provides access to different remaster and persistence tools in MX Linux</source>
         <translation>MX Linux で異なるリマスターとパーシステンス ツールを提供するプログラム</translation>
     </message>
     <message>
-        <location filename="mxremastercc.cpp" line="103"/>
+        <location filename="../mainwindow.cpp" line="107"/>
         <source>Copyright (c) MX Linux</source>
         <translation>Copyright (c) MX Linux</translation>
     </message>
     <message>
-        <location filename="mxremastercc.cpp" line="104"/>
+        <location filename="../mainwindow.cpp" line="108"/>
         <source>License</source>
         <translation>ライセンス</translation>
     </message>
     <message>
-        <location filename="mxremastercc.cpp" line="105"/>
+        <location filename="../mainwindow.cpp" line="109"/>
         <source>Changelog</source>
         <translation>更新履歴</translation>
     </message>
     <message>
-        <location filename="mxremastercc.cpp" line="106"/>
+        <location filename="../mainwindow.cpp" line="110"/>
         <source>Cancel</source>
         <translation>キャンセル</translation>
     </message>
     <message>
-        <location filename="mxremastercc.cpp" line="122"/>
+        <location filename="../mainwindow.cpp" line="128"/>
         <source>&amp;Close</source>
         <translation>閉じる(&amp;C)</translation>
     </message>
